@@ -1043,7 +1043,7 @@ class rcmail extends rcube
 
             // Trash subfolders
             $delimiter  = $storage->get_hierarchy_delimiter();
-            $subfolders = array_reverse($storage->list_folders('', $trash_mbox . $delimiter . '*'));
+            $subfolders = array_reverse($storage->list_folders($trash_mbox . $delimiter, '*'));
             $last       = '';
 
             foreach ($subfolders as $folder) {
@@ -1180,7 +1180,8 @@ class rcmail extends rcube
             return rtrim($path, '/') . '/';
         }
 
-        $path = preg_replace('/[?&].*$/', '', (string) $path);
+        $path = preg_replace('/index\.php.*$/', '', (string) $path);
+        $path = preg_replace('/[?&].*$/', '', $path);
         $path = preg_replace('![^/]+$!', '', $path);
 
         return rtrim($path, '/') . '/';
