@@ -66,6 +66,7 @@ class rcube_charset
         '222'           => 'WINDOWS-874',
         '238'           => 'WINDOWS-1250',
         'MS950'         => 'CP950',
+        'WINDOWS31J'    => 'CP932',
         'WINDOWS949'    => 'UHC',
         'WINDOWS1257'   => 'ISO-8859-13',
         'ISO2022JP'     => 'ISO-2022-JP-MS',
@@ -190,7 +191,7 @@ class rcube_charset
     {
         static $charsets = [];
 
-        $charset = strtoupper($input);
+        $charset = strtoupper((string) $input);
 
         if (isset($charsets[$input])) {
             return $charsets[$input];
@@ -299,9 +300,6 @@ class rcube_charset
         catch (Throwable $e) {
             $out = false;
         }
-        catch (Exception $e) {
-            $out = false;
-        }
 
         restore_error_handler();
         mb_substitute_character($mbstring_sc);
@@ -339,9 +337,6 @@ class rcube_charset
             catch (Throwable $e) {
                 $out = false;
             }
-            catch (Exception $e) {
-                $out = false;
-            }
 
             restore_error_handler();
 
@@ -354,6 +349,46 @@ class rcube_charset
         return $str;
     }
 
+    /**
+     * Check if the specified input string matches one of the provided charsets.
+     * This includes UTF-32, UTF-16, RCUBE_CHARSET and default_charset.
+     *
+     * @param string $str  Input string
+     * @param array  $from Suspected charsets of the input string
+     *
+     * @return string|null First matching charset
+     */
+    public static function check($str, $charsets = [])
+    {
+        $chunk = strlen($str) > 100 * 1024 ? substr($str, 0, 100 * 1024) : $str;
+
+        // Add dehault charset, system charset and easily detectable charset to the list
+        if (substr($chunk, 0, 4) == "\0\0\xFE\xFF") $charsets[] = 'UTF-32BE';
+        if (substr($chunk, 0, 4) == "\xFF\xFE\0\0") $charsets[] = 'UTF-32LE';
+        if (substr($chunk, 0, 2) == "\xFE\xFF")     $charsets[] = 'UTF-16BE';
+        if (substr($chunk, 0, 2) == "\xFF\xFE")     $charsets[] = 'UTF-16LE';
+
+        // heuristics
+        if (preg_match('/\x00\x00\x00[^\x00]/', $chunk))    $charsets[] = 'UTF-32BE';
+        if (preg_match('/[^\x00]\x00\x00\x00/', $chunk))    $charsets[] = 'UTF-32LE';
+        if (preg_match('/\x00[^\x00]\x00[^\x00]/', $chunk)) $charsets[] = 'UTF-16BE';
+        if (preg_match('/[^\x00]\x00[^\x00]\x00/', $chunk)) $charsets[] = 'UTF-16LE';
+
+        $charsets[] = RCUBE_CHARSET;
+        $charsets[] = (string) rcube::get_instance()->config->get('default_charset');
+
+        $charsets = array_map(['rcube_charset', 'parse_charset'], $charsets);
+        $charsets = array_unique(array_filter($charsets));
+
+        foreach ($charsets as $charset) {
+            $ret = self::convert($chunk, $charset);
+
+            if ($ret === rcube_charset::clean($ret)) {
+                return $charset;
+            }
+        }
+    }
+
     /**
      * Converts string from standard UTF-7 (RFC 2152) to UTF-8.
      *
@@ -421,6 +456,7 @@ class rcube_charset
      * @param string $language User language
      *
      * @return string Charset name
+     * @deprecated
      */
     public static function detect($string, $failover = null, $language = null)
     {
@@ -443,16 +479,16 @@ class rcube_charset
             $language = $rcube->get_user_language();
         }
 
-        // Prioritize charsets according to current language (#1485669)
+        // Prioritize charsets according to the current language (#1485669)
         $prio = null;
         switch ($language) {
         case 'ja_JP':
-            $prio = ['ISO-2022-JP', 'JIS', 'UTF-8', 'EUC-JP', 'eucJP-win', 'SJIS', 'SJIS-win'];
+            $prio = ['ISO-2022-JP', 'JIS', 'UTF-8', 'EUC-JP', 'eucJP-win', 'SJIS'];
             break;
 
         case 'zh_CN':
         case 'zh_TW':
-            $prio = ['UTF-8', 'BIG-5', 'GB2312', 'EUC-TW'];
+            $prio = ['UTF-8', 'BIG-5', 'EUC-TW', 'GB18030'];
             break;
 
         case 'ko_KR':
@@ -479,19 +515,28 @@ class rcube_charset
         }
 
         if (function_exists('mb_detect_encoding')) {
+            $exclude = 'BASE64,UUENCODE,HTML-ENTITIES,Quoted-Printable,'
+                . '7bit,8bit,pass,wchar,byte2be,byte2le,byte4be,byte4le,'
+                . 'UCS-4,UCS-4BE,UCS-4LE,UCS-2,UCS-2BE,UCS-2LE';
+
             if (empty($prio)) {
-                $prio = ['UTF-8', 'SJIS', 'GB2312',
+                $prio = [
+                    'UTF-8',
                     'ISO-8859-1', 'ISO-8859-2', 'ISO-8859-3', 'ISO-8859-4',
                     'ISO-8859-5', 'ISO-8859-6', 'ISO-8859-7', 'ISO-8859-8', 'ISO-8859-9',
                     'ISO-8859-10', 'ISO-8859-13', 'ISO-8859-14', 'ISO-8859-15', 'ISO-8859-16',
-                    'WINDOWS-1252', 'WINDOWS-1251', 'EUC-JP', 'EUC-TW', 'KOI8-R', 'BIG-5',
-                    'ISO-2022-KR', 'ISO-2022-JP',
+                    'WINDOWS-1252', 'WINDOWS-1251', 'WINDOWS-1254',
+                    'EUC-JP', 'EUC-TW', 'KOI8-R', 'BIG-5', 'ISO-2022-KR', 'ISO-2022-JP', 'GB18030',
                 ];
             }
 
-            $encodings = array_unique(array_merge($prio, mb_list_encodings()));
+            // We have to remove unwanted/uncommon encodings from the list.
+            // This is needed especially on PHP >= 8.1
+            $all_encodings = array_diff(mb_list_encodings(), explode(',', $exclude));
 
-            if ($encoding = mb_detect_encoding($string, $encodings)) {
+            $encodings = array_unique(array_merge($prio, $all_encodings));
+
+            if ($encoding = mb_detect_encoding($string, $encodings, true)) {
                 return $encoding;
             }
         }
