@@ -748,8 +748,8 @@ class rcube_utils
      */
     public static function parse_host_uri($host, $plain_port = null, $ssl_port = null)
     {
-        if (strpos($host, 'unix://') === 0) {
-            return [$host, 'unix', -1];
+        if (preg_match('#^(unix|ldapi)://#i', $host, $matches)) {
+            return [$host, $matches[1], -1];
         }
 
         $url    = parse_url($host);
@@ -1509,12 +1509,17 @@ class rcube_utils
         }
 
         if (strpos($format, 'u') !== false) {
-            $dt  = number_format(microtime(true), 6, '.', '');
-            $dt .=  '.' . date_default_timezone_get();
+            $dt = number_format(microtime(true), 6, '.', '');
+
+            try {
+                $date = date_create_from_format('U.u', $dt);
+                $date->setTimeZone(new DateTimeZone(date_default_timezone_get()));
 
-            if ($date = date_create_from_format('U.u.e', $dt)) {
                 return $date->format($format);
             }
+            catch (Exception $e) {
+                // ignore, fallback to date()
+            }
         }
 
         return date($format);
